package com.ruoyi.bst.bindRecord.mapper;

import java.util.List;
import com.ruoyi.bst.bindRecord.domain.BindRecord;
import com.ruoyi.bst.bindRecord.domain.BindRecordVO;
import com.ruoyi.bst.bindRecord.domain.BindRecordQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 设备绑定记录Mapper接口
 *
 * @author ruoyi
 * @date 2025-04-24
 */
public interface BindRecordMapper
{
    /**
     * 查询设备绑定记录
     *
     * @param recordId 设备绑定记录主键
     * @return 设备绑定记录
     */
    BindRecordVO selectBindRecordByRecordId(Long recordId);

    /**
     * 查询设备绑定记录列表
     *
     * @param query 设备绑定记录
     * @return 设备绑定记录集合
     */
    List<BindRecordVO> selectBindRecordList(@Param("query")BindRecordQuery query);

    /**
     * 新增设备绑定记录
     *
     * @param bindRecord 设备绑定记录
     * @return 结果
     */
    int insertBindRecord(BindRecord bindRecord);

    /**
     * 批量新增设备绑定记录
     */
    int batchInsert(@Param("list") List<? extends BindRecord> list);

    /**
     * 批量修改设备绑定记录
     */
    int batchUpdate(@Param("list") List<? extends BindRecord> list);

    /**
     * 修改设备绑定记录
     *
     * @param bindRecord 设备绑定记录
     * @return 结果
     */
    public int updateBindRecord(@Param("data") BindRecord bindRecord);

    /**
     * 删除设备绑定记录
     *
     * @param recordId 设备绑定记录主键
     * @return 结果
     */
    int deleteBindRecordByRecordId(Long recordId);

    /**
     * 批量删除设备绑定记录
     *
     * @param recordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBindRecordByRecordIds(Long[] recordIds);
}
